@@ -1,5 +1,5 @@
-use serde_json::Value;
-
+use bson::Bson;
+use crate::db::db_adapter::DataDecoder;
 use crate::db::DriverType;
 use crate::Result;
 
@@ -70,13 +70,13 @@ impl StmtConvert for DriverType {
 ///json convert
 pub trait JsonCodec {
     /// to an json value
-    fn try_to_json(self) -> Result<Value>;
+    fn try_to_bson(self) -> Result<Bson>;
 }
 
 ///json convert
 pub trait RefJsonCodec {
     /// to an json value
-    fn try_to_json(&self) -> Result<Value>;
+    fn try_to_bson(&self,decoder: &dyn DataDecoder) -> Result<Bson>;
 }
 
 ///result convert
@@ -85,13 +85,13 @@ pub trait ResultCodec<T> {
 }
 
 #[macro_export]
-macro_rules! new_json_option_into {
+macro_rules! to_bson_macro {
     ($r:ident) => {
                {
                     if $r.is_some() {
-                         $r.unwrap().into()
+                         bson::bson!($r.unwrap())
                     } else {
-                        serde_json::Value::Null
+                         bson::Bson::Null
                     }
                 }
     };
