@@ -15,7 +15,7 @@ use sqlx_core::value::ValueRef;
 
 use crate::convert::{JsonCodec, RefJsonCodec, ResultCodec};
 use crate::postgres::PgInterval;
-use chrono::{Local, Utc};
+use chrono::{Utc};
 
 use crate::{to_bson_macro};
 use std::option::Option::Some;
@@ -188,20 +188,18 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                 return Ok(to_bson(&r).unwrap_or_default());
             }
             "TIMESTAMP" => {
-                let r: Option<chrono::DateTime<Local>> = Decode::<'_, Postgres>::decode(self)?;
-                if let Some(r) = r {
-                    let dt = bson::DateTime::from_chrono(r);
-                    return Ok(Bson::DateTime(dt));
+                let r: Option<chrono::NaiveDateTime> = Decode::<'_, Postgres>::decode(self)?;
+                if let Some(dt) = r {
+                    return Ok(Bson::String(dt.format("%Y-%m-%dT%H:%M:%S").to_string()));
                 }
                 return Ok(Bson::Null);
             }
             "TIMESTAMP[]" => {
-                let r: Option<Vec<chrono::DateTime<Local>>> = Decode::<'_, Postgres>::decode(self)?;
+                let r: Option<Vec<chrono::NaiveDateTime>> = Decode::<'_, Postgres>::decode(self)?;
                 if let Some(r) = r {
                     let mut dts = vec![];
-                    for x in r {
-                        let dt = bson::DateTime::from_chrono(x);
-                        dts.push(Bson::DateTime(dt));
+                    for dt in r {
+                        dts.push(Bson::String(dt.format("%Y-%m-%dT%H:%M:%S").to_string()));
                     }
                     return Ok(Bson::Array(dts));
                 }
@@ -209,9 +207,8 @@ impl<'c> JsonCodec for PgValueRef<'c> {
             }
             "TIMESTAMPTZ" => {
                 let r: Option<chrono::DateTime<Utc>> = Decode::<'_, Postgres>::decode(self)?;
-                if let Some(r) = r {
-                    let dt = bson::DateTime::from_chrono(r);
-                    return Ok(Bson::DateTime(dt));
+                if let Some(dt) = r {
+                    return Ok(Bson::String(dt.to_string()));
                 }
                 return Ok(Bson::Null);
             }
@@ -221,7 +218,7 @@ impl<'c> JsonCodec for PgValueRef<'c> {
                     let mut dts = vec![];
                     for x in r {
                         let dt = bson::DateTime::from_chrono(x);
-                        dts.push(Bson::DateTime(dt));
+                        dts.push(Bson::String(dt.to_string()));
                     }
                     return Ok(Bson::Array(dts));
                 }
